@@ -5,9 +5,7 @@ from pathlib import Path
 
 def setup_cmdline_args_for_docly_gen(parser: ArgumentParser):
     parser.add_argument("--no_generate_diff", action="store_false", 
-                        help="Do not generate the diff")
-    parser.add_argument("--print_report", action="store_true",
-                        help="Print the report")
+                        help="Do not generate the diff. Only prints a report on the console")
     parser.add_argument("--no_generate_args_list", action="store_false",
                         help="Do not generate argument list in the docstring")
     #####################
